package mschmidt.komo;
/*
 * Calls classes that configure workbench.  
 */

import mschmidt.komo.preferences.PreferenceConstants;

import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.application.IWorkbenchConfigurer;
import org.eclipse.ui.application.IWorkbenchWindowConfigurer;
import org.eclipse.ui.application.WorkbenchAdvisor;
import org.eclipse.ui.application.WorkbenchWindowAdvisor;

public class ApplicationWorkbenchAdvisor extends WorkbenchAdvisor {
	/**
	 * Set the application initial perspective.
	 */
	private static final String PERSPECTIVE_ID = "mschmidt.komo.komoperspective";

	/**
	 * Overrides org.eclipse.ui.application.
	 * WorkbenchAdvisor.createWorkbenchWindowAdvisor.
	 * 
	 * @param configurer is the IWorkbenchConfigurer 
	 * 
	 * @return AppWorkbenchWindowAdvisor
	 */
	@Override
    public final WorkbenchWindowAdvisor createWorkbenchWindowAdvisor(
    		final IWorkbenchWindowConfigurer configurer) {
        return new ApplicationWorkbenchWindowAdvisor(configurer);
    }

    /**
     * Overrides org.eclipse.ui.application.
     * WorkbenchAdvisor.initialize.
     * 
     * @param configurer is the IWorkbenchConfigurer
     */
//	@Override
    public final void initialize(final IWorkbenchConfigurer configurer) {
        super.initialize(configurer);
        configurer.setSaveAndRestore(true);
    }
    
    /**
     * 
     * @return PERSPECTIVE_ID
     */
	@Override
	public final String getInitialWindowPerspectiveId() {
		return PERSPECTIVE_ID;
	}

	/**
	 * Overrides org.eclipse.ui.application.
	 * WorkbenchWindowAdvisor.preShutdown 
	 * to add an exit confirmation.
	 * 
	 * @return retVal true to shutdown, false to abort shutdown
	 */
	@Override
	public final boolean preShutdown() {
		boolean retVal = true;
		if (KomoPlugin.getDefault().getPreferenceStore().
			getBoolean(PreferenceConstants.CONFIRM_EXIT)) {
			String messageString = new String(); 
			if (Application.dbConn.dbLock.getDepth() > 0) {
				messageString = "Database connection is active.\nProcessing may be interrupted by exiting.\n\nAre you sure you want to exit?";
			} else {
				messageString = "Database connection is inactive.\nIt is safe to exit.\n\nAre you sure you want to exit?";
			}
			retVal = MessageDialog.openQuestion(
				PlatformUI.getWorkbench().
				getActiveWorkbenchWindow().getShell(), 
				"Confirm Exit", 
				messageString);
		}
		return retVal;
	}
}

